#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor lua53
%define mod_name luafilesystem
%define pversion 1.8.0
%define _pversion 1_8_0

%if %{undefined lua_provides}
%define lua_provides \
Provides: lua-%{mod_name} = %{version}-%{release} \
Obsoletes: lua-%{mod_name} < %{version}-%{release}
%endif

Version:        %{pversion}
Release:        6.5
Summary:        Filesystem support for Lua
License:        MIT
Group:          Development/Libraries/Other
URL:            https://lunarmodules.github.io/luafilesystem/
Source:         https://github.com/lunarmodules/luafilesystem/archive/v%{_pversion}.tar.gz#/%{mod_name}-%{version}.tar.gz
BuildRequires:  %{flavor}-devel
Requires:       %{flavor}
%lua_provides
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif

%description
LuaFileSystem is a Lua library developed to complement the set of functions
related to file systems offered by the standard Lua distribution.

LuaFileSystem offers a portable way to access the underlying directory
structure and file attributes.

%prep
%setup -q -n %{mod_name}-%{_pversion}

sed -i 's|@@VERSION@@|%{version}|g' Makefile

%build
make %{?_make_output_sync} CFLAGS="%{optflags} -fPIC -I%{lua_incdir}"

%install
%make_install LUA_LIBDIR='%{lua_archdir}'

%files
%doc doc/us/*
%{lua_archdir}/lfs.so

%changelog
* Thu Mar 16 2023 Matej Cepl <mcepl@suse.com>
- Change upstream homepage to the current one at Lunar Modules.
* Wed Jan 25 2023 Michal Suchanek <msuchanek@suse.de>
- Opencode %%make_build to prevent build failure when not defined.
* Tue Jan  3 2023 Egbert Eich <eich@suse.com>
- Handle Leap 15 / SLE-15 where %%lua_provides is not supported.
* Wed Jan 27 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%lua_provides macro
* Mon Jul  6 2020 Matej Cepl <mcepl@suse.com>
- Add lua54 as new build target
* Thu Apr 23 2020 Matej Cepl <mcepl@suse.com>
- Update to 1.8.0:
  - Lua 5.4 support
  - lfs.link and lfs.symlinkattributes now work on Windows
  - MACOSX_DEPLOYMENT_TARGET is configurable in the Makefile
  - Fallback to _POSIX_PATH_MAX when MAXPATHLEN is not avaliable
  - Fixed memory leak in case of realloc failure
* Sun Dec 24 2017 avindra@opensuse.org
- Fix target folder name in tarball
* Tue Nov  7 2017 aavindraa@gmail.com
- Update to version 1.7.0:
  * symlinkattributes function now provides 'target' field,
    containing name of the file that the symlink points to.
  * attributes, symlinkattributes, touch, mkdir, and rmdir functions
    now return system-dependent error code as the third value on error.
  * Fixed detection of closed files for Lua 5.2+ in setmode, lock,
    and unlock functions.
  * Fixed various compiler warnings.
* Mon Oct 30 2017 jmatejek@suse.com
- do not build for Lua 5.2
* Fri Aug 11 2017 eich@suse.com
- Add defines for the version number and a version number string
  with '_' (underscores) to keep these close together and in sync.
* Thu Aug 10 2017 eich@suse.com
- Fix provides/obsoletes for the old package name.
* Thu Jul 13 2017 tchvatal@suse.com
- Switch to multibuild syntax to produce results for all lua flavors
* Wed Jan  4 2017 eich@suse.com
- Replaced 'makeinstall' by 'make_install'.
* Mon Oct 17 2016 eich@suse.com
- Setting 'download_files' service to mode='localonly'
  and adding source tarball. (Required for Factory).
* Tue Oct 11 2016 eich@suse.com
- Update to version 1.6.3:
  * Lua 5.3 support.
  * Assorted bugfixes.
- Use source services
- Make use of lua macros
- Add Requires for lua
- Add -fPIC compiler flag
* Wed Jan 29 2014 kianseong@gmail.com
- Initial Version
